@@ -310,7 +310,15 @@ class QueryPlanner():
                                         )
             integration_select.where = find_and_remove_time_filter(integration_select.where, time_filter)
             integration_selects = [integration_select]
-
+        elif isinstance(time_filter, BinaryOperation) and time_filter.op == '=' and time_filter.args[1] == Latest():
+            integration_select = Select(targets=[Star()],
+                                        from_table=table,
+                                        where=preparation_where,
+                                        order_by=order_by,
+                                        limit=Constant(predictor_window),
+                                        )
+            integration_select.where = find_and_remove_time_filter(integration_select.where, time_filter)
+            integration_selects = [integration_select]
         elif isinstance(time_filter, BinaryOperation) and time_filter.op in ('>', '>='):
             time_filter_date = time_filter.args[1]
             preparation_time_filter_op = {'>': '<=', '>=': '<'}[time_filter.op]
@@ -405,6 +413,9 @@ class QueryPlanner():
         right_table_path = right_table.to_string(alias=False)
 
         new_condition_args = []
+
+        if join.condition is None:
+            raise PlanningException('Join between two tables must have ON clause')
         for arg in join.condition.args:
             if isinstance(arg, Identifier):
                 if left_table_path in arg.parts:
@@ -481,6 +492,23 @@ class QueryPlanner():
 
         if isinstance(join_left, Select):
             # dbt query.
+
+            # move latest into subquery
+            moved_conditions = []
+
+            def move_latest(node, **kwargs):
+                if isinstance(node, BinaryOperation):
+                    if Latest() in node.args:
+                        for arg in node.args:
+                            if isinstance(arg, Identifier):
+                                # remove table alias
+                                arg.parts = [arg.parts[-1]]
+                        moved_conditions.append(node)
+
+            query_traversal(query.where, move_latest)
+
+            # TODO make project step from query.target
+
             # TODO support complex query. Only one table is supported at the moment.
             if not isinstance(join_left.from_table, Identifier):
                 raise PlanningException(f'Statement not supported: {query.to_string()}')
@@ -493,6 +521,13 @@ class QueryPlanner():
             else:
                 table_alias = query.from_table.parts
 
+            # add latest to query.where
+            for cond in moved_conditions:
+                if query.where is not None:
+                    query.where = BinaryOperation('and', args=[query.where, cond])
+                else:
+                    query.where = cond
+
             def add_aliases(node, is_table, **kwargs):
                 if not is_table and isinstance(node, Identifier):
                     if len(node.parts) == 1:
